@@ -9,11 +9,11 @@ from rest_framework.exceptions import ValidationError
 from rest_framework.response import Response
 from rest_framework.views import APIView
 
-import core_website_app.components.account_request.api as account_request_api
 from core_main_app.access_control.exceptions import AccessControlError
 from core_main_app.commons import exceptions
 from core_main_app.commons.exceptions import ApiError
 from core_main_app.utils.decorators import api_staff_member_required
+import core_website_app.components.account_request.api as account_request_api
 
 
 class AbstractActionAccountRequest(APIView, metaclass=ABCMeta):
@@ -84,4 +84,6 @@ class AbstractActionAccountRequest(APIView, metaclass=ABCMeta):
             return Response(content, status=status.HTTP_400_BAD_REQUEST)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
