@@ -9,9 +9,9 @@ from rest_framework.exceptions import ValidationError
 from rest_framework.response import Response
 from rest_framework.views import APIView
 
-import core_website_app.components.account_request.api as account_request_api
 from core_main_app.commons import exceptions
 from core_main_app.utils.decorators import api_staff_member_required
+import core_website_app.components.account_request.api as account_request_api
 from core_website_app.rest.account_request.abstract_views import (
     AbstractActionAccountRequest,
 )
@@ -45,13 +45,17 @@ class AccountRequestList(APIView):
             account_request_list = account_request_api.get_all()
 
             # Serialize object
-            serializer = AccountRequestSerializer(account_request_list, many=True)
+            serializer = AccountRequestSerializer(
+                account_request_list, many=True
+            )
 
             # Return response
             return Response(serializer.data, status=status.HTTP_200_OK)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
     def post(self, request):
         """Create a new account request
@@ -82,13 +86,15 @@ class AccountRequestList(APIView):
             serializer = UserSerializer(data=request.data)
 
             # Validate request
-            serializer.is_valid(True)
+            serializer.is_valid(raise_exception=True)
 
             # Save request
             account_request = serializer.save()
 
             # Account request serializer
-            account_request_serializer = AccountRequestSerializer(account_request)
+            account_request_serializer = AccountRequestSerializer(
+                account_request
+            )
 
             # Return the serialized user request
             return Response(
@@ -99,7 +105,9 @@ class AccountRequestList(APIView):
             return Response(content, status=status.HTTP_400_BAD_REQUEST)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
 
 class AccountRequestDetail(APIView):
@@ -159,7 +167,9 @@ class AccountRequestDetail(APIView):
             return Response(content, status=status.HTTP_404_NOT_FOUND)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
 
 class AccountRequestDeny(AbstractActionAccountRequest):
