@@ -9,16 +9,18 @@ from django.shortcuts import redirect
 from django.template.loader import get_template
 from django.urls import reverse
 
+from core_main_app.commons.exceptions import ApiError
+from core_main_app.utils.markdown_parser import parse
+from core_main_app.utils.rendering import render
 import core_website_app.components.account_request.api as account_request_api
 import core_website_app.components.contact_message.api as contact_message_api
 import core_website_app.components.help.api as help_api
 import core_website_app.components.privacy_policy.api as privacy_policy_api
-import core_website_app.components.rules_of_behavior.api as rules_of_behavior_api
+from core_website_app.components.rules_of_behavior import (
+    api as rules_of_behavior_api,
+)
 import core_website_app.components.terms_of_use.api as terms_of_use_api
-from core_main_app.commons.exceptions import ApiError
-from core_main_app.commons.validators import validate_password
-from core_main_app.utils.markdown_parser import parse
-from core_main_app.utils.rendering import render
+
 from core_website_app.components.contact_message.models import ContactMessage
 from core_website_app.settings import DISPLAY_NIST_HEADERS
 from .forms import RequestAccountForm, ContactForm
@@ -34,7 +36,10 @@ def request_new_account(request):
     """
     assets = {
         "js": [
-            {"path": "core_website_app/user/js/user_account_req.js", "is_raw": False}
+            {
+                "path": "core_website_app/user/js/user_account_req.js",
+                "is_raw": False,
+            }
         ],
         "css": ["core_website_app/user/css/list.css"],
     }
@@ -45,7 +50,6 @@ def request_new_account(request):
             # Call the API
             try:
                 request_form_data = request_form.cleaned_data
-                validate_password(request_form_data.get("password1"))
 
                 user = User(
                     username=request_form_data.get("username"),
@@ -64,36 +68,51 @@ def request_new_account(request):
                     "User Account Request sent to the administrator.",
                 )
                 return redirect(reverse("core_main_app_homepage"))
-            except ApiError as e:
-                error_message = str(e)
-
-                error_template = get_template(
-                    "core_website_app/user/request_error.html"
-                )
-                error_box = error_template.render({"error_message": error_message})
-
-                return render(
-                    request,
-                    "core_website_app/user/request_new_account.html",
-                    assets=assets,
-                    context={"request_form": request_form, "action_result": error_box},
-                )
-            except ValidationError as e:
-                error_message = "The following error(s) occurred during " "validation:"
-                error_items = [str(error) for error in e.messages]
+            except ApiError as exception:
+                error_message = str(exception)
 
                 error_template = get_template(
                     "core_website_app/user/request_error.html"
                 )
                 error_box = error_template.render(
-                    {"error_message": error_message, "error_items": error_items}
+                    {"error_message": error_message}
                 )
 
                 return render(
                     request,
                     "core_website_app/user/request_new_account.html",
                     assets=assets,
-                    context={"request_form": request_form, "action_result": error_box},
+                    context={
+                        "request_form": request_form,
+                        "action_result": error_box,
+                        "page_title": "Account Request",
+                    },
+                )
+            except ValidationError as exception:
+                error_message = (
+                    "The following error(s) occurred during " "validation:"
+                )
+                error_items = [str(error) for error in exception.messages]
+
+                error_template = get_template(
+                    "core_website_app/user/request_error.html"
+                )
+                error_box = error_template.render(
+                    {
+                        "error_message": error_message,
+                        "error_items": error_items,
+                    }
+                )
+
+                return render(
+                    request,
+                    "core_website_app/user/request_new_account.html",
+                    assets=assets,
+                    context={
+                        "request_form": request_form,
+                        "action_result": error_box,
+                        "page_title": "Account Request",
+                    },
                 )
     else:
         request_form = RequestAccountForm()
@@ -102,7 +121,10 @@ def request_new_account(request):
         request,
         "core_website_app/user/request_new_account.html",
         assets=assets,
-        context={"request_form": request_form},
+        context={
+            "request_form": request_form,
+            "page_title": "Account Request",
+        },
     )
 
 
@@ -138,7 +160,7 @@ def contact(request):
     return render(
         request,
         "core_website_app/user/contact.html",
-        context={"contact_form": contact_form},
+        context={"contact_form": contact_form, "page_title": "Contact"},
     )
 
 
@@ -156,7 +178,9 @@ def help_page(request):
         help_page_object.content = parse(help_page_object.content)
 
     return render(
-        request, "core_website_app/user/help.html", context={"help": help_page_object}
+        request,
+        "core_website_app/user/help.html",
+        context={"help": help_page_object, "page_title": "Help"},
     )
 
 
@@ -177,7 +201,9 @@ def privacy_policy(request):
         policy.content = parse(policy.content)
 
     return render(
-        request, "core_website_app/user/privacy-policy.html", context={"policy": policy}
+        request,
+        "core_website_app/user/privacy-policy.html",
+        context={"policy": policy, "page_title": "Privacy Policy"},
     )
 
 
@@ -195,7 +221,9 @@ def terms_of_use(request):
         terms.content = parse(terms.content)
 
     return render(
-        request, "core_website_app/user/terms-of-use.html", context={"terms": terms}
+        request,
+        "core_website_app/user/terms-of-use.html",
+        context={"terms": terms, "page_title": "Terms of Use"},
     )
 
 
@@ -210,10 +238,15 @@ def rules_of_behavior(request):
     # Call the API
     rules_of_behavior_object = rules_of_behavior_api.get()
     if rules_of_behavior_object is not None:
-        rules_of_behavior_object.content = parse(rules_of_behavior_object.content)
+        rules_of_behavior_object.content = parse(
+            rules_of_behavior_object.content
+        )
 
     return render(
         request,
         "core_website_app/user/rules_of_behavior.html",
-        context={"rules_of_behavior": rules_of_behavior_object},
+        context={
+            "rules_of_behavior": rules_of_behavior_object,
+            "page_title": "Rules of Behavior",
+        },
     )
