@@ -2,19 +2,28 @@
 """
 
 from django.core import mail
-from django.test import TestCase
+from django.test import TestCase, override_settings
+from unittest.mock import patch
+
 import core_website_app.components.contact_message.api as contact_message_api
 from core_website_app.components.contact_message.models import ContactMessage
-from mock import patch
 
 
 class TestSendEmailContactMessage(TestCase):
+    """Test Send Email Contact Message"""
+
     def setUp(self):
+        """setUp"""
 
         self.contact_message = _create_contact_message()
 
-    @patch("core_website_app.components.contact_message.models.ContactMessage.save")
+    @override_settings(SEND_EMAIL_WHEN_CONTACT_MESSAGE_IS_RECEIVED=True)
+    @patch(
+        "core_website_app.components.contact_message.models"
+        ".ContactMessage.save"
+    )
     def test_contact_message_send_mail(self, mock_save):
+        """test_contact_message_send_mail"""
 
         # Arrange
         mock_save.return_value = self.contact_message
@@ -24,10 +33,18 @@ class TestSendEmailContactMessage(TestCase):
 
         # Assert
         self.assertEqual(len(mail.outbox), 1)
-        self.assertEqual(mail.outbox[0].subject, "[Django] New Contact Message")
+        self.assertEqual(
+            mail.outbox[0].subject, "[Django] New Contact Message"
+        )
 
-    @patch("core_website_app.components.contact_message.models.ContactMessage.save")
+    @override_settings(SEND_EMAIL_WHEN_CONTACT_MESSAGE_IS_RECEIVED=True)
+    @patch(
+        "core_website_app.components.contact_message.models"
+        ".ContactMessage.save"
+    )
     def test_contact_message_send_mail_admins(self, mock_save):
+        """test_contact_message_send_mail_admins"""
+
         # Arrange
         mock_save.return_value = self.contact_message
 
@@ -36,7 +53,23 @@ class TestSendEmailContactMessage(TestCase):
 
         # Assert
         self.assertEqual(len(mail.outbox[0].to), 2)
-        self.assertEqual(mail.outbox[0].to, ["admin1@test.com", "admin2@test.com"])
+        self.assertEqual(
+            mail.outbox[0].to, ["admin1@test.com", "admin2@test.com"]
+        )
+
+    @override_settings(SEND_EMAIL_WHEN_CONTACT_MESSAGE_IS_RECEIVED=False)
+    @patch(
+        "core_website_app.components.contact_message.models"
+        ".ContactMessage.save"
+    )
+    def test_contact_message_send_mail_when_disabled(self, mock_save):
+        # Arrange
+        mock_save.return_value = self.contact_message
+
+        # Act
+        contact_message_api.upsert(self.contact_message)
+        # Assert
+        self.assertEqual(len(mail.outbox), 0)
 
 
 def _create_contact_message(
