@@ -1,3 +1,6 @@
+"""  Test settings
+"""
+
 from django.conf import settings
 
 SECRET_KEY = "fake-key"
@@ -9,8 +12,12 @@ INSTALLED_APPS = [
     "django.contrib.contenttypes",
     "django.contrib.sites",
     "django.contrib.sessions",
+    # Extra apps
+    "captcha",
     # Local app
     "tests",
+    "core_main_app",
+    "core_website_app",
 ]
 
 LOGGING = {
@@ -65,3 +72,21 @@ SEND_EMAIL_WHEN_CONTACT_MESSAGE_IS_RECEIVED = getattr(
 )
 """ boolean: send an email when a contact message is received
 """
+
+DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"
+CELERYBEAT_SCHEDULER = "django_celery_beat.schedulers:DatabaseScheduler"
+
+SEND_EMAIL_WHEN_CONTACT_MESSAGE_IS_RECEIVED = getattr(
+    settings, "SEND_EMAIL_WHEN_CONTACT_MESSAGE_IS_RECEIVED", True
+)
+
+SEND_EMAIL_WHEN_ACCOUNT_REQUEST_IS_ACCEPTED = getattr(
+    settings, "SEND_EMAIL_WHEN_ACCOUNT_REQUEST_IS_ACCEPTED", False
+)
+SEND_EMAIL_WHEN_ACCOUNT_REQUEST_IS_DENIED = getattr(
+    settings, "SEND_EMAIL_WHEN_ACCOUNT_REQUEST_IS_DENIED", False
+)
+ROOT_URLCONF = "core_website_app.urls"
+
+MONGODB_INDEXING = False
+MONGODB_ASYNC_SAVE = False
